<?php

namespace Litecms\Coupan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Coupan\Models\Coupan;

class CoupanPolicy
{

    /**
     * Determine if the given user can view the coupan.
     *
     * @param UserPolicy $user
     * @param Coupan $coupan
     *
     * @return bool
     */
    public function view(UserPolicy $user, Coupan $coupan)
    {
        if ($user->canDo('coupan.coupan.view') && $user->isAdmin()) {
            return true;
        }

        return $coupan->user_id == user_id() && $coupan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a coupan.
     *
     * @param UserPolicy $user
     * @param Coupan $coupan
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('coupan.coupan.create');
    }

    /**
     * Determine if the given user can update the given coupan.
     *
     * @param UserPolicy $user
     * @param Coupan $coupan
     *
     * @return bool
     */
    public function update(UserPolicy $user, Coupan $coupan)
    {
        if ($user->canDo('coupan.coupan.edit') && $user->isAdmin()) {
            return true;
        }

        return $coupan->user_id == user_id() && $coupan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given coupan.
     *
     * @param UserPolicy $user
     * @param Coupan $coupan
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Coupan $coupan)
    {
        return $coupan->user_id == user_id() && $coupan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given coupan.
     *
     * @param UserPolicy $user
     * @param Coupan $coupan
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Coupan $coupan)
    {
        if ($user->canDo('coupan.coupan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given coupan.
     *
     * @param UserPolicy $user
     * @param Coupan $coupan
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Coupan $coupan)
    {
        if ($user->canDo('coupan.coupan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
