<?php

namespace Litecms\Coupan\Providers;

use Illuminate\Support\ServiceProvider;

class CoupanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'coupan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'coupan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.coupan', function ($app) {
            return $this->app->make('Litecms\Coupan\Coupan');
        });

                // Bind Coupan to repository
        $this->app->bind(
            'Litecms\Coupan\Interfaces\CoupanRepositoryInterface',
            \Litecms\Coupan\Repositories\Eloquent\CoupanRepository::class
        );

        $this->app->register(\Litecms\Coupan\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Coupan\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.coupan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/coupan.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/coupan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/coupan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
